@@ -1,8 +1,8 @@
 package TestApp::Model::CDBI::User;
 
+eval { require Class::DBI }; return 1 if $@;
+@ISA = qw/TestApp::Model::CDBI/;
 use strict;
-use warnings;
-use base 'TestApp::Model::CDBI::CDBI';
 
 __PACKAGE__->table  ( 'user' );
 __PACKAGE__->columns( Primary   => qw/id/ );
